@@ -18,23 +18,22 @@ __all__ = ['MayBe']
 
 from collections.abc import Callable, Iterator, Sequence
 from typing import cast, Final, overload
-from pythonic_fp.sentinels.flavored import Sentinel
+from pythonic_fp.gadgets.sentinels.flavored import Sentinel
 
 
 class MayBe[D]:
     """
-    Maybe Monad
-    -----------
+    .. admonition:: Maybe Monad
 
-    Data structure wrapping a potentially missing item.
+        Data structure wrapping a potentially missing item.
 
-    Immutable semantics
+        Immutable semantics
 
-    - can store any item of any type, including ``None``
+        - can store any item of any type, including ``None``
 
-      - with one hidden implementation dependent exception
+        - with one hidden implementation dependent exception
 
-    - immutable semantics, therefore covariant
+        - immutable semantics
 
     .. warning::
 
